@@ -2,22 +2,24 @@
 {-# LANGUAGE OverloadedStrings #-}
 
 module Network.Run.Core (
-    resolve
-  , openSocket
-  , openServerSocket
-  ) where
+    resolve,
+    openSocket,
+    openServerSocket,
+    gclose,
+) where
 
 import qualified Control.Exception as E
 import Network.Socket
 
 resolve :: SocketType -> Maybe HostName -> ServiceName -> Bool -> IO AddrInfo
 resolve socketType mhost port passive =
-        head <$> getAddrInfo (Just hints) mhost (Just port)
+    head <$> getAddrInfo (Just hints) mhost (Just port)
   where
-    hints = defaultHints {
-        addrSocketType = socketType
-      , addrFlags = if passive then [AI_PASSIVE] else []
-      }
+    hints =
+        defaultHints
+            { addrSocketType = socketType
+            , addrFlags = if passive then [AI_PASSIVE] else []
+            }
 
 #if !MIN_VERSION_network(3,1,2)
 openSocket :: AddrInfo -> IO Socket
@@ -30,3 +32,10 @@ openServerSocket addr = E.bracketOnError (openSocket addr) close $ \sock -> do
     withFdSocket sock $ setCloseOnExecIfNeeded
     bind sock $ addrAddress addr
     return sock
+
+gclose :: Socket -> IO ()
+#if MIN_VERSION_network(3,1,1)
+gclose sock = gracefulClose sock 5000
+#else
+gclose = close
+#endif
